[pbs-devel] [PATCH proxmox-backup] tasks: bump archive to 100k entries

Fabian Grünbichler f.gruenbichler at proxmox.com
Wed Jul 8 10:04:24 CEST 2020


1000 are way too few, but it probably makes sense to make this value
configurable in the future.

Signed-off-by: Fabian Grünbichler <f.gruenbichler at proxmox.com>
---
or even think about encoding the datastore in the TaskInfo/UPID (almost
all regular tasks are datastore specific), which would allow setting a
default and per-datastore limit.

 src/server/worker_task.rs | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/server/worker_task.rs b/src/server/worker_task.rs
index 72c594e6..89c0e115 100644
--- a/src/server/worker_task.rs
+++ b/src/server/worker_task.rs
@@ -304,9 +304,10 @@ fn update_active_workers(new_upid: Option<&UPID>) -> Result<Vec<TaskListInfo>, E
 
     // assemble list without duplicates
     // we include all active tasks,
     // and fill up to 1000 entries with finished tasks
 
-    let max = 1000;
+    let max = 100000;
 
     let mut task_hash = HashMap::new();
 
@@ -304,9 +304,10 @@ fn update_active_workers(new_upid: Option<&UPID>) -> Result<Vec<TaskListInfo>, E
     // assemble list without duplicates
     // we include all active tasks,
-    // and fill up to 1000 entries with finished tasks
+    // and fill up to 100000 entries with finished tasks
+    // TODO: make configurable ?
 
-- 
2.20.1






More information about the pbs-devel mailing list